//-*-c++-*-
#ifndef Tulip_InducedSubGraphSelection_H
#define Tulip_InducedSubGraphSelection_H

#include <tulip/TulipPlugin.h>
///
class InducedSubGraphSelection:public Selection
{ 
public:
  ///
  InducedSubGraphSelection(const PropertyContext &);
  ///
  ~InducedSubGraphSelection();
  ///
  bool run();
};

#endif




